@@ -5,14 +5,24 @@ extends qw(MouseX::NativeTraits::MethodProvider);
 
 sub generate_set {
     my($self) = @_;
-    my $writer     = $self->writer;
-    return sub { $writer->( $_[0], 1 ) };
+    my $writer = $self->writer;
+    return sub {
+        if(@_ != 1) {
+            $self->argument_error('set', 1, 1, scalar @_);
+        }
+        $writer->( $_[0], 1 );
+    };
 }
 
 sub generate_unset {
     my($self) = @_;
-    my $writer     = $self->writer;
-    return sub { $writer->( $_[0], 0 ) };
+    my $writer = $self->writer;
+    return sub {
+        if(@_ != 1) {
+            $self->argument_error('unset', 1, 1, scalar @_);
+        }
+        $writer->( $_[0], 0 );
+    };
 }
 
 sub generate_toggle {
@@ -20,13 +30,23 @@ sub generate_toggle {
     my $reader     = $self->reader;
     my $writer     = $self->writer;
 
-    return sub { $writer->( $_[0], !$reader->( $_[0] ) ) };
+    return sub {
+        if(@_ != 1) {
+            $self->argument_error('toggle', 1, 1, scalar @_);
+        }
+        $writer->( $_[0], !$reader->( $_[0] ) );
+    };
 }
 
 sub generate_not {
     my($self) = @_;
-    my $reader     = $self->reader;
-    return sub { !$reader->( $_[0] ) };
+    my $reader = $self->reader;
+    return sub {
+        if(@_ != 1) {
+            $self->argument_error('not', 1, 1, scalar @_);
+        }
+        !$reader->( $_[0] );
+    };
 }
 
 no Mouse;
